<?php
/* Copyright (C) 2017 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) ---Put here your own copyright and developer email---
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

/**
 *   	\file       article_card.php
 *		\ingroup    lareponse
 *		\brief      Page to create/edit/view article
 */

//if (! defined('NOREQUIREDB'))              define('NOREQUIREDB','1');					// Do not create database handler $db
//if (! defined('NOREQUIREUSER'))            define('NOREQUIREUSER','1');				// Do not load object $user
//if (! defined('NOREQUIRESOC'))             define('NOREQUIRESOC','1');				// Do not load object $mysoc
//if (! defined('NOREQUIRETRAN'))            define('NOREQUIRETRAN','1');				// Do not load object $langs
//if (! defined('NOSCANGETFORINJECTION'))    define('NOSCANGETFORINJECTION','1');		// Do not check injection attack on GET parameters
//if (! defined('NOSCANPOSTFORINJECTION'))   define('NOSCANPOSTFORINJECTION','1');		// Do not check injection attack on POST parameters
//if (! defined('NOCSRFCHECK'))              define('NOCSRFCHECK','1');					// Do not check CSRF attack (test on referer + on token if option MAIN_SECURITY_CSRF_WITH_TOKEN is on).
//if (! defined('NOTOKENRENEWAL'))           define('NOTOKENRENEWAL','1');				// Do not roll the Anti CSRF token (used if MAIN_SECURITY_CSRF_WITH_TOKEN is on)
//if (! defined('NOSTYLECHECK'))             define('NOSTYLECHECK','1');				// Do not check style html tag into posted data
//if (! defined('NOREQUIREMENU'))            define('NOREQUIREMENU','1');				// If there is no need to load and show top and left menu
//if (! defined('NOREQUIREHTML'))            define('NOREQUIREHTML','1');				// If we don't need to load the html.form.class.php
//if (! defined('NOREQUIREAJAX'))            define('NOREQUIREAJAX','1');       	  	// Do not load ajax.lib.php library
//if (! defined("NOLOGIN"))                  define("NOLOGIN",'1');						// If this page is public (can be called outside logged session). This include the NOIPCHECK too.
//if (! defined('NOIPCHECK'))                define('NOIPCHECK','1');					// Do not check IP defined into conf $dolibarr_main_restrict_ip
//if (! defined("MAIN_LANG_DEFAULT"))        define('MAIN_LANG_DEFAULT','auto');					// Force lang to a particular value
//if (! defined("MAIN_AUTHENTICATION_MODE")) define('MAIN_AUTHENTICATION_MODE','aloginmodule');		// Force authentication handler
//if (! defined("NOREDIRECTBYMAINTOLOGIN"))  define('NOREDIRECTBYMAINTOLOGIN',1);		// The main.inc.php does not make a redirect if not logged, instead show simple error message
//if (! defined("FORCECSP"))                 define('FORCECSP','none');					// Disable all Content Security Policies


// Load Dolibarr environment
$res = 0;
// Try main.inc.php into web root known defined into CONTEXT_DOCUMENT_ROOT (not always defined)
if (!$res && !empty($_SERVER["CONTEXT_DOCUMENT_ROOT"])) $res = @include $_SERVER["CONTEXT_DOCUMENT_ROOT"]."/main.inc.php";
// Try main.inc.php into web root detected using web root calculated from SCRIPT_FILENAME
$tmp = empty($_SERVER['SCRIPT_FILENAME']) ? '' : $_SERVER['SCRIPT_FILENAME']; $tmp2 = realpath(__FILE__); $i = strlen($tmp) - 1; $j = strlen($tmp2) - 1;
while ($i > 0 && $j > 0 && isset($tmp[$i]) && isset($tmp2[$j]) && $tmp[$i] == $tmp2[$j]) { $i--; $j--; }
if (!$res && $i > 0 && file_exists(substr($tmp, 0, ($i + 1))."/main.inc.php")) $res = @include substr($tmp, 0, ($i + 1))."/main.inc.php";
if (!$res && $i > 0 && file_exists(dirname(substr($tmp, 0, ($i + 1)))."/main.inc.php")) $res = @include dirname(substr($tmp, 0, ($i + 1)))."/main.inc.php";
// Try main.inc.php using relative path
if (!$res && file_exists("../main.inc.php")) $res = @include "../main.inc.php";
if (!$res && file_exists("../../main.inc.php")) $res = @include "../../main.inc.php";
if (!$res && file_exists("../../../main.inc.php")) $res = @include "../../../main.inc.php";
if (!$res) die("Include of main fails");

require_once DOL_DOCUMENT_ROOT.'/core/class/html.formcompany.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/html.formfile.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/doleditor.class.php';
dol_include_once('/lareponse/class/article.class.php');
dol_include_once('/lareponse/class/comment.class.php');
dol_include_once('/lareponse/class/tag.class.php');
dol_include_once('/lareponse/class/export.class.php');
dol_include_once('/lareponse/lib/lareponse_favorites.lib.php');
dol_include_once('/lareponse/lib/lareponse_article.lib.php');
dol_include_once('/h2g2/lib/h2g2.lib.php');

// Load translation files required by the page
$langs->loadLangs(array("lareponse@lareponse", "other"));

// Get parameters
$id = GETPOST('id', 'int');
$ref        = GETPOST('ref', 'alpha');
$action = GETPOST('action', 'aZ09');
$confirm    = GETPOST('confirm', 'alpha');
$cancel     = GETPOST('cancel', 'aZ09');
$contextpage = GETPOST('contextpage', 'aZ') ?GETPOST('contextpage', 'aZ') : 'articlecard'; // To manage different context of search
$backtopage = GETPOST('backtopage', 'alpha');
$backtopageforcancel = GETPOST('backtopageforcancel', 'alpha');
$optioncss = GETPOST('optioncss', 'alpha');
//$lineid   = GETPOST('lineid', 'int');

$order = GETPOST('order');
if ($order == 'ASC' || $order == 'DESC')
	$_SESSION['order'] = $order;

// Initialize technical objects
$object = new Article($db);
$tag = new Tag($db);
$extrafields = new ExtraFields($db);
$diroutputmassaction = $conf->lareponse->dir_output.'/temp/massgeneration/'.$user->id;
$hookmanager->initHooks(array('articlecard', 'globalcard')); // Note that conf->hooks_modules contains array

// Fetch optionals attributes and labels
$extrafields->fetch_name_optionals_label($object->table_element);

$search_array_options = $extrafields->getOptionalsFromPost($object->table_element, '', 'search_');

// Initialize array of search criterias
$search_all = trim(GETPOST("search_all", 'alpha'));
$search = array();
foreach ($object->fields as $key => $val) {
	if (GETPOST('search_'.$key, 'alpha')) $search[$key] = GETPOST('search_'.$key, 'alpha');
}

if (empty($action) && empty($id) && empty($ref)) $action = 'view';

// Load object
include DOL_DOCUMENT_ROOT.'/core/actions_fetchobject.inc.php'; // Must be include, not include_once.

// Security check - Protection if external user
//if ($user->socid > 0) accessforbidden();
//if ($user->socid > 0) $socid = $user->socid;
//$isdraft = (($object->statut == $object::STATUS_DRAFT) ? 1 : 0);
//$result = restrictedArea($user, 'lareponse', $object->id, '', '', 'fk_soc', 'rowid', $isdraft);

$permissiontoread = $user->rights->lareponse->article->read;
$permissiontoadd = $user->rights->lareponse->article->write; // Used by the include of actions_addupdatedelete.inc.php and actions_lineupdown.inc.php
$permissiontodelete = $user->rights->lareponse->article->delete || ($permissiontoadd && isset($object->status) && $object->status == $object::STATUS_DRAFT);
$permissionnote = $user->rights->lareponse->article->write; // Used by the include of actions_setnotes.inc.php
$permissiondellink = $user->rights->lareponse->article->write; // Used by the include of actions_dellink.inc.php
$permissioncorrector = $user->rights->lareponse->article->correct; // For edit/delete of an article
$permissiontoexport = $user->rights->lareponse->article->export;
$permissiontopublish = $user->rights->lareponse->article->publish;
$upload_dir = $conf->lareponse->multidir_output[isset($object->entity) ? $object->entity : 1];

// Change permissions due to corrector permissions
if ($permissioncorrector) {
	$permissiontoadd = 1;
	$permissiontodelete = 1;
}


if ((!doArticleAndCurrentEntityMatches($object) && $id) || !isArticleAccessible($id, $action)) accessforbidden();
if ((!doArticleAndCurrentEntityMatches($object) && $id)) accessforbidden();

if ($action == 'create' || $action == 'edit') {
	print '<script src="https://ajax.googleapis.com/ajax/libs/jquery/2.1.1/jquery.min.js"></script>
<script src="https://cdn.rawgit.com/harvesthq/chosen/gh-pages/chosen.jquery.min.js"></script>
<link href="https://cdn.rawgit.com/harvesthq/chosen/gh-pages/chosen.min.css" rel="stylesheet"/>
<link href="https://maxcdn.bootstrapcdn.com/font-awesome/4.6.1/css/font-awesome.min.css" rel="stylesheet" />';
}

/*
 * Actions
 */

$parameters = array();
$reshook = $hookmanager->executeHooks('doActions', $parameters, $object, $action); // Note that $action and $object may have been modified by some hooks
if ($reshook < 0) setEventMessages($hookmanager->error, $hookmanager->errors, 'errors');

if ($action == 'comment' && $_POST['content']) {
	$newComment = new ArticleComment($db);
	$newComment->content = $_POST['content'];
	$newComment->fk_article = $id;
	$newComment->entity = $conf->entity;
	$error = $newComment->create($user);
	if ($error) setEventMessages($langs->trans('CommentPost'), '', 'mesgs');
	else setEventMessages($langs->trans('ErrorCommentPost'), '', 'errors');
	$action = ''; // TODO send mail to every body who fav this article
	exit(header('Location: '.$_SERVER['PHP_SELF'].'?id='.$id));
}

if ($action == 'deletecomment' && GETPOST('confirm') == 'yes' && GETPOST('commentid', 'int')) {
	$deleteComment = new ArticleComment($db);
	$deleteComment->fetch(GETPOST('commentid', 'int'));
	$error = $deleteComment->delete($user);
	if ($error > 0) setEventMessages($langs->trans('CommentDelete'), '', 'mesgs');
	else setEventMessages($langs->trans('ErrorCommentDelete'), '', 'errors');
	exit(header('Location: '.$_SERVER['PHP_SELF'].'?id='.$id));
	$action = '';
}

if ($action == 'confirm_export' && GETPOST('confirm') == 'yes') {
	$export = new LareponseExport();

	$ids = array((string) $id);
	if ($export->generateJsonFile($ids)) {
		if (!$export->downloadExportFile($ids)) {
			setEventMessages($langs->trans('ArticleFailureExport'), '', 'errors');
		}
	} else {
		setEventMessages($langs->trans('ArticleFailureExport'), '', 'errors');
	}
	$action = '';
}

if ($action == 'confirm_publish' && GETPOST('confirm') == 'yes') {
	if ($object->generateArticleToken()) {
		setEventMessages('PublishSuccess', '', 'mesgs');
	} else {
		setEventMessages('PublishFail', '', 'errors');
	}
	$action = '';
	exit(header('Location: '.$_SERVER['PHP_SELF'].'?id='.$id));
}

if ($action == 'confirm_unpublish' && GETPOST('confirm') == 'yes') {
	if ($object->removeArticleToken()) {
		setEventMessages('UnPublishSuccess', '', 'mesgs');
	} else {
		setEventMessages('UnPublishFail', '', 'errors');
	}
	$action = '';
	exit(header('Location: '.$_SERVER['PHP_SELF'].'?id='.$id));
}

//add an element into lareponse_favorites database

if (empty($reshook)) {
	$error = 0;

	$backurlforlist = dol_buildpath('/lareponse/article_list.php', 1);

	if (empty($backtopage) || ($cancel && empty($id))) {
		if (empty($backtopage) || ($cancel && strpos($backtopage, '__ID__'))) {
			if (empty($id) && (($action != 'add' && $action != 'create') || $cancel)) $backtopage = $backurlforlist;
			else $backtopage = dol_buildpath('/lareponse/article_card.php', 1).'?id='.($id > 0 ? $id : '__ID__');
		} else {
			exit(header('Location: '.$backurlforlist));
		}
	} else if ($cancel && !empty($id)) {
		exit(header('Location: '.$_SERVER['PHP_SELF'].'?id='.$id));
		$action = '';
	}
	if ((float) DOL_VERSION < 9.0)
		$backtopage = $backurlforlist;

	$triggermodname = 'LAREPONSE_ARTICLE_MODIFY'; // Name of trigger action code to execute when we modify record

	// Action add
	if ($action == 'add' && !empty($permissiontoadd)) {
		foreach ($object->fields as $key => $val) {
			if ($object->fields[$key]['type'] == 'duration') {
				if (GETPOST($key.'hour') == '' && GETPOST($key.'min') == '') continue; // The field was not submited to be edited
			} else {
				if (!GETPOSTISSET($key)) continue; // The field was not submited to be edited
			}
			// Ignore special fields
			if (in_array($key, array('rowid', 'entity', 'date_creation', 'tms', 'fk_user_creat', 'fk_user_modif', 'import_key'))) continue;

			// Set value to insert
			if (in_array($object->fields[$key]['type'], array('text', 'html'))) {
				$value = GETPOST($key, 'none');
			} elseif ($object->fields[$key]['type'] == 'date') {
				$value = dol_mktime(12, 0, 0, GETPOST($key.'month', 'int'), GETPOST($key.'day', 'int'), GETPOST($key.'year', 'int'));
			} elseif ($object->fields[$key]['type'] == 'datetime') {
				$value = dol_mktime(GETPOST($key.'hour', 'int'), GETPOST($key.'min', 'int'), 0, GETPOST($key.'month', 'int'), GETPOST($key.'day', 'int'), GETPOST($key.'year', 'int'));
			} elseif ($object->fields[$key]['type'] == 'duration') {
				$value = 60 * 60 * GETPOST($key.'hour', 'int') + 60 * GETPOST($key.'min', 'int');
			} elseif (preg_match('/^(integer|price|real|double)/', $object->fields[$key]['type'])) {
				$value = price2num(GETPOST($key, 'none')); // To fix decimal separator according to lang setup
			} else {
				$value = GETPOST($key, 'alphanohtml');
			}
			if (preg_match('/^integer:/i', $object->fields[$key]['type']) && $value == '-1') $value = ''; // This is an implicit foreign key field
			if (!empty($object->fields[$key]['foreignkey']) && $value == '-1') $value = ''; // This is an explicit foreign key field

			//var_dump($key.' '.$value.' '.$object->fields[$key]['type']);
			$object->$key = $value;
			if ($val['notnull'] > 0 && $object->$key == '' && !is_null($val['default']) && $val['default'] == '(PROV)') {
				$object->$key = '(PROV)';
			}
			if ($val['notnull'] > 0 && $object->$key == '' && is_null($val['default'])) {
				$error++;
				setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv($val['label'])), null, 'errors');
			}
		}

		// Set Entity value
		$object->entity = $conf->entity;

		if (!$error) {
			$result = $object->create($user);
			if ($result > 0) {
				// Creation OK
				$tag->linkArticleTag($object->id, GETPOST('list_tag', 'array'));

				$urltogo = dol_buildpath('/lareponse/article_card.php?id='.$object->id.'&action=edit', 1); // Redirect to edit mode if creation was a success
				header("Location: ".$urltogo);
				exit;
			} else {
				// Creation KO
				if (!empty($object->errors)) setEventMessages(null, $object->errors, 'errors');
				else setEventMessages($object->error, null, 'errors');
				$action = 'create';
			}
		} else {
			$action = 'create';
		}
	}

	//Action update
	if ($action == 'update' && !empty($permissiontoadd)) {
		foreach ($object->fields as $key => $val) {
			$object->tms = dol_now();
			// Check if field was submited to be edited
			if ($object->fields[$key]['type'] == 'duration') {
				if (!GETPOSTISSET($key.'hour') || !GETPOSTISSET($key.'min')) continue; // The field was not submited to be edited
			} else {
				if (!GETPOSTISSET($key)) continue; // The field was not submited to be edited
			}
			// Ignore special fields
			//if (in_array($key, array('rowid', 'entity', 'date_creation', 'tms', 'fk_user_creat', 'fk_user_modif', 'import_key'))) continue;

			// Set value to update
			if (in_array($object->fields[$key]['type'], array('text', 'html'))) {
				$value = GETPOST($key, 'none');
			} elseif ($object->fields[$key]['type'] == 'date') {
				$value = dol_mktime(12, 0, 0, GETPOST($key.'month'), GETPOST($key.'day'), GETPOST($key.'year'));
			} elseif ($object->fields[$key]['type'] == 'datetime') {
				$value = dol_mktime(GETPOST($key.'hour'), GETPOST($key.'min'), 0, GETPOST($key.'month'), GETPOST($key.'day'), GETPOST($key.'year'));
			} elseif ($object->fields[$key]['type'] == 'duration') {
				if (GETPOST($key.'hour', 'int') != '' || GETPOST($key.'min', 'int') != '') {
					$value = 60 * 60 * GETPOST($key.'hour', 'int') + 60 * GETPOST($key.'min', 'int');
				} else {
					$value = '';
				}
			} elseif (preg_match('/^(integer|price|real|double)/', $object->fields[$key]['type'])) {
				$value = price2num(GETPOST($key, 'none'));	// To fix decimal separator according to lang setup
			} else {
				$value = GETPOST($key, 'alpha');
			}
			if (preg_match('/^integer:/i', $object->fields[$key]['type']) && $value == '-1') $value = ''; // This is an implicit foreign key field
			if (!empty($object->fields[$key]['foreignkey']) && $value == '-1') $value = ''; // This is an explicit foreign key field

			$object->$key = $value;
			if ($val['notnull'] > 0 && $object->$key == '' && is_null($val['default'])) {
				$error++;
				setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv($val['label'])), null, 'errors');
			}
		}

		if (!$error) {
			$result = $object->update($user);
			if ($result > 0) {
				// Update OK
				$error = $tag->updateArticleTag($object->id, GETPOST('list_tag', 'array'));
				if ($error < 0) setEventMessages($langs->trans('ErrorArticleUpdate'), '', 'errors');
				else setEventMessages($langs->trans('ArticleUpdate'), '', 'mesgs');
				$action = 'view';
				exit(header('Location: '.$_SERVER['PHP_SELF'].'?id='.$id));
			} else {
				// Creation KO
				setEventMessages($object->error, $object->errors, 'errors');
				$action = 'edit';
			}
		} else {
			$action = 'edit';
		}
	}

	// Actions cancel, update_extras, confirm_validate, confirm_delete, confirm_deleteline, confirm_clone, confirm_close, confirm_setdraft, confirm_reopen
	include dol_buildpath('/lareponse/lareponse_actions.php');

	// Actions when linking object each other
	include DOL_DOCUMENT_ROOT.'/core/actions_dellink.inc.php';

	// Actions when printing a doc from card
	include DOL_DOCUMENT_ROOT.'/core/actions_printing.inc.php';

	// Action to move up and down lines of object
	//include DOL_DOCUMENT_ROOT.'/core/actions_lineupdown.inc.php';

	// Action to build doc
	include DOL_DOCUMENT_ROOT.'/core/actions_builddoc.inc.php';

	if ($action == 'set_thirdparty' && $permissiontoadd) {
		$object->setValueFrom('fk_soc', GETPOST('fk_soc', 'int'), '', '', 'date', '', $user, 'ARTICLE_MODIFY');
	}
	if ($action == 'classin' && $permissiontoadd) {
		$object->setProject(GETPOST('projectid', 'int'));
	}

	// Actions to send emails
	$triggersendname = 'ARTICLE_SENTBYMAIL';
	$autocopy = 'MAIN_MAIL_AUTOCOPY_ARTICLE_TO';
	$trackid = 'article'.$object->id;
	include DOL_DOCUMENT_ROOT.'/core/actions_sendmails.inc.php';
}




/*
 * View
 *
 * Put here all code to build page
 */

$form = new Form($db);
$formfile = new FormFile($db);

$arrayofjs = array(
	"https://cdn.rawgit.com/harvesthq/chosen/gh-pages/chosen.jquery.min.js",
	"https://cdn.jsdelivr.net/npm/mermaid/dist/mermaid.min.js"
);
$arrayofcss = array(
	"/lareponse/css/chosen.min.css"
);
llxHeader('', $langs->trans('article'), '', '', 0, 0, $arrayofjs, $arrayofcss);


// Part to create
if ($action == 'create') {
	$title = '<i class="fa fa-newspaper-o" style="color:black;" aria-hidden="true"></i> '.$langs->trans('lareponseNewArticle');
	print load_fiche_titre($title, '', '');

	print '<form method="POST" action="'.$_SERVER["PHP_SELF"].'">';
	if ((float) DOL_VERSION >= 11) {
		print '<input type="hidden" name="token" value="' . newToken() . '">';
	} else {
		print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
	}
	print '<input type="hidden" name="action" value="add">';
	if ($backtopage) print '<input type="hidden" name="backtopage" value="'.$backtopage.'">';
	if ($backtopageforcancel) print '<input type="hidden" name="backtopageforcancel" value="'.$backtopageforcancel.'">';

	dol_fiche_head(array(), '');

	print '<table class="border centpercent tableforfieldcreate">'."\n";

	// Common attributes
	//include DOL_DOCUMENT_ROOT.'/core/tpl/commonfields_add.tpl.php';

	foreach ($object->fields as $key => $val) {
		if (in_array($key, array('content', 'private'))) continue;

		// Discard if extrafield is a hidden field on form
		if (abs($val['visible']) != 1 && abs($val['visible']) != 3 && abs($val['visible']) != 4) continue;

		if (array_key_exists('enabled', $val) && isset($val['enabled']) && ! verifCond($val['enabled'])) continue;	// We don't want this field

		print '<tr id="field_'.$key.'">';
		print '<td';
		print ' class="titlefieldcreate';
		if ($val['notnull'] > 0) print ' fieldrequired';
		if ($val['type'] == 'text' || $val['type'] == 'html') print ' tdtop';
		print '"';
		print '>';
		if (!empty($val['help'])) print $form->textwithpicto($langs->trans($val['label']), $langs->trans($val['help']));
		else print $langs->trans($val['label']);
		print '</td>';
		print '<td>';
		if (in_array($val['type'], array('int', 'integer'))) $value = GETPOST($key, 'int');
		elseif ($val['type'] == 'text' || $val['type'] == 'html') $value = GETPOST($key, 'none');
		else $value = GETPOST($key, 'alpha');
		print $object->showInputField($val, $key, $value, '', '', '', 0);
		print '</td>';
		print '</tr>';
	}


	// Other attributes
	include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_add.tpl.php';

	//print '</table>'."\n";

	print '</table>';


	dol_fiche_end();

	print '<div class="center">';
	print '<input type="submit" class="button" name="add" value="'.dol_escape_htmltag($langs->trans("Create")).'">';
	print '&nbsp; ';
	print '<input type="'.($backtopage ? "submit" : "button").'" class="button" name="cancel" value="'.dol_escape_htmltag($langs->trans("Cancel")).'"'.($backtopage ? '' : ' onclick="javascript:history.go(-1)"').'>'; // Cancel for create does not post form if we don't know the backtopage
	print '</div>';

	print '</form>';

	//dol_set_focus('input[name="ref"]');
}

// Part to edit record
if (($id || $ref) && $action == 'edit') {
	$title = '<i class="fa fa-newspaper-o" style="color:black;" aria-hidden="true"></i> '.$langs->trans("ArticleCard");
	print load_fiche_titre($title, '', '');

	print '<form method="POST" action="'.$_SERVER["PHP_SELF"].'">';
	if ((float) DOL_VERSION >= 11) {
		print '<input type="hidden" name="token" value="' . newToken() . '">';
	} else {
		print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
	}
	print '<input type="hidden" name="action" value="update">';
	print '<input type="hidden" name="id" value="'.$object->id.'">';
	if ($backtopage) print '<input type="hidden" name="backtopage" value="'.$backtopage.'">';
	if ($backtopageforcancel) print '<input type="hidden" name="backtopageforcancel" value="'.$backtopageforcancel.'">';

	dol_fiche_head();

	print '<table class="border centpercent tableforfieldedit">'."\n";

	// Common attributes
	// Common attributes
	//include DOL_DOCUMENT_ROOT.'/core/tpl/commonfields_edit.tpl.php';

	foreach ($object->fields as $key => $val) {
		if ($key == 'content') continue;
		// Discard if extrafield is a hidden field on form
		if (abs($val['visible']) != 1 && abs($val['visible']) != 3 && abs($val['visible']) != 4) continue;

		if (array_key_exists('enabled', $val) && isset($val['enabled']) && ! verifCond($val['enabled'])) continue;	// We don't want this field

		print '<tr><td';
		print ' class="titlefieldcreate';
		if ($val['notnull'] > 0) print ' fieldrequired';
		if ($val['type'] == 'text' || $val['type'] == 'html') print ' tdtop';
		print '">';
		if (! empty($val['help'])) print $form->textwithpicto($langs->trans($val['label']), $langs->trans($val['help']));
		else print $langs->trans($val['label']);
		print '</td>';
		print '<td>';
		if (in_array($val['type'], array('int', 'integer'))) $value = GETPOSTISSET($key)?GETPOST($key, 'int'):$object->$key;
		elseif ($val['type'] == 'text' || $val['type'] == 'html') $value = GETPOSTISSET($key)?GETPOST($key, 'none'):$object->$key;
		else $value = GETPOSTISSET($key)?GETPOST($key, 'alpha'):$object->$key;
		//var_dump($val.' '.$key.' '.$value);
		if ($key == 'private' && $object->fk_user_creat != $user->id) {
			print ($object->private == 0 ? $langs->trans('Public') : $langs->trans('Private'));
		} elseif ($val['noteditable']) print $object->showOutputField($val, $key, $value, '', '', '', 0);
		else print $object->showInputField($val, $key, $value, '', '', '', 0);
		print '</td>';
		print '</tr>';
	}


	// Other attributes
	include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_add.tpl.php';

	// Tag
	print '<tr>';
	print '<td class="fieldrequired">Tag</td>';
	$tag->printSelectTag($langs, $id);
	print '</tr>';

	print '</table>';

	// Content
	print '<table>';
	print '<tr id="field_content">';
	print '<td class="titlefieldcreate fieldrequired tdtop">'.$langs->trans('LaReponseContent').'</td>';
	print '</tr>';
	print '</table>';
	$doleditor=new DolEditor('content', $object->content, '', 500, 'article_content', 'In', true, true, $conf->fckeditor->enabled, ROWS_7, '90%');
	$doleditor->Create();

	dol_fiche_end();
	print '<div class="tabsAction"><input type="submit" class="button" name="save" value="'.$langs->trans("Save").'">';
	print ' &nbsp; <input type="submit" class="button" name="cancel" value="'.$langs->trans("Cancel").'">';

	if ($permissiontodelete) {
		print '<a class="butActionDelete" href="'.$_SERVER["PHP_SELF"].'?id='.$object->id.'&amp;action=delete&token='.newToken().'">'.$langs->trans('Delete').'</a>'."\n";
	} else {
		print '<a class="butActionRefused classfortooltip" href="#" title="' . dol_escape_htmltag($langs->trans("NotEnoughPermissions")) . '">' . $langs->trans('Delete') . '</a>' . "\n";
	}
	print '</div>';

	print '</form>';
}

// Part to show record
if ($object->id > 0 && (empty($action) || ($action != 'edit' && $action != 'create'))) {
	$res = $object->fetch_optionals();

	// Basic display if we're not in print mode
	if ($optioncss !== 'print') {
		$head = articlePrepareHead($object);
		dol_fiche_head($head, 'card', $langs->trans("article"), -1, $object->picto);

		$formconfirm = '';

		// Confirmation to delete
		if ($action == 'delete') {
			$formconfirm = $form->formconfirm($_SERVER["PHP_SELF"].'?id='.$object->id, $langs->trans('Deletearticle'), $langs->trans('ConfirmDeleteObject'), 'confirm_delete', '', 0, 1);
		}
		// Confirmation to delete line
		if ($action == 'deleteline') {
			$formconfirm = $form->formconfirm($_SERVER["PHP_SELF"].'?id='.$object->id.'&lineid='.$lineid, $langs->trans('DeleteLine'), $langs->trans('ConfirmDeleteLine'), 'confirm_deleteline', '', 0, 1);
		}
		// Clone confirmation
		if ($action == 'clone') {
			// Create an array for form
			$formquestion = array();
			$formconfirm = $form->formconfirm($_SERVER["PHP_SELF"].'?id='.$object->id, $langs->trans('ToClone'), $langs->trans('ConfirmClonearticle', $object->ref).'<br><i class="fa fa-exclamation-triangle"></i> '.$langs->trans('WarningTagsDoesntClone'), 'confirm_clone', $formquestion, 'yes', 1);
		}


		// Export confirmation
		if ($action == 'export' && $permissiontoexport) {
			$formconfirm = $form->formconfirm($_SERVER["PHP_SELF"].'?id='.$object->id, $langs->trans('ExportArticle'), $langs->trans('ConfirmExportArticle').'<br><i class="fa fa-exclamation-triangle"></i> '.$langs->trans('WarningConfirmExport'), 'confirm_export', '', 0, 1);
		}

		// Publish confirmation
		if ($action == 'publish' && $permissiontopublish) {
			$formconfirm = $form->formconfirm($_SERVER["PHP_SELF"].'?id='.$object->id, $langs->trans('PublicPublish'), $langs->trans('ConfirmPubliclyPublish'), 'confirm_publish', '', 0, 1);
		}

		// Unpublish confirmation
		if ($action == 'unpublish' && $permissiontopublish) {
			$formconfirm = $form->formconfirm($_SERVER["PHP_SELF"].'?id='.$object->id, $langs->trans('PublicUnPublish'), $langs->trans('ConfirmPubliclyUnPublish'), 'confirm_unpublish', '', 0, 1);
		}


		// Confirmation of action xxxx
		if ($action == 'xxx') {
			$formquestion = array();
			$formconfirm = $form->formconfirm($_SERVER["PHP_SELF"].'?id='.$object->id, $langs->trans('XXX'), $text, 'confirm_xxx', $formquestion, 0, 1, 220);
		}

		// Call Hook formConfirm
		$parameters = array('formConfirm' => $formconfirm, 'lineid' => $lineid);
		$reshook = $hookmanager->executeHooks('formConfirm', $parameters, $object, $action); // Note that $action and $object may have been modified by hook
		if (empty($reshook)) $formconfirm .= $hookmanager->resPrint;
		elseif ($reshook > 0) $formconfirm = $hookmanager->resPrint;

		// Print form confirm
		print $formconfirm;


		// Object card
		// ------------------------------------------------------------
		$linkback = '<a href="'.dol_buildpath('/lareponse/article_list.php', 1).'?restore_lastsearch_values=1'.(!empty($socid) ? '&socid='.$socid : '').'">'.$langs->trans("BackToList").'</a>';

		$morehtmlref = '<div class="refidno">';

		$morehtmlref .= '</div>';

		// Tag for banner tab
		$tagArticleList = $tag->getArticleTag($id);
		$tagList = $tag->getAllTag();

		$collapseTagButton = '<span id="lareponse-tags-icon" class="fas fa-chevron-up"></span>';

		$tagDiv = '';

		if (count($tagArticleList) > 6) {
			$tagDiv = $collapseTagButton;
		}

		$tagDiv .= '<br><br><div id="tags-section">';

		foreach ($tagArticleList as $tagVal) {
			$tagId = intval($tagVal['id']);
			$tag->fetch($tagId);
			switch ($tagVal['type']) {
				case 0:
					$type = $langs->trans('product');
					break;
				case 1:
					$type = $langs->trans('supplier');
					break;
				case 2:
					$type = 'Tiers';
					break;
				case 3:
					$type = $langs->trans('member');
					break;
				case 4:
					$type = $langs->trans('contact');
					break;
				case 5:
					$type = $langs->trans('bank_account');
					break;
				case 6:
					$type = $langs->trans('project');
					break;
				case 7:
					$type = $langs->trans('user');
					break;
				case 12:
					$type = 'Ticket';
					break;
				case 43:
					$type = 'LaReponse';
					break;
				default:
					$type = 'GestionParc';
			}
			$ways = $tag->print_all_ways(' &gt;&gt; <span class="fa fa-tag"></span> ', dol_buildpath('/lareponse/article_list.php', 1));
			$tagData = $ways[0];
			// Some colors added by categories module may be empty or missing a '#'. We're here changing the string so that it matches a #XXXXXX pattern or becomes black if empty
			mb_substr($tagVal['color'], 0, 1) == '#' ? $currcolor = $tagVal['color'] : $currcolor = '#'.$tagVal['color'];
			if (strlen($currcolor) == 1) {
				$currcolor .= '000000';
			}
			$tagDiv .= '<div><a style="background-color: '.$currcolor.'; color:'.(colorIsLight($currcolor) ? 'black' : 'white').' !important;" class="lareponse_tag" href="'.dol_buildpath('/lareponse/card_tag.php', 1).'?id='.$tagVal['id'].'"><span class="fa fa-tag"></span> '.$tagData . ' ('. $type.')</a></div>';
		}
		$tagDiv .= '</div>';

		if (!empty($conf->lareponse->enabled) && $user->rights->lareponse->article->read) {
			$obj = new Article($db);
			$obj->fetch($id);
			$createdBy = '';
			$createdBy .= '<table>';
			$createdBy .= '<tr><td>';
			$createdBy .= $langs->trans('CreatedBy');
			$commentUser = new User($db);
			$commentUser->fetch($obj->fk_user_creat);
			$createdBy .= activeContributorUrl($commentUser, 1);
			$createdBy .= '</td>';
			$createdBy .= '<td>'. $langs->trans('The') . ' ' . dol_print_date($obj->date_creation, 'dayhour', 'tzuserrel').'</td>';
			$createdBy .= '</tr>';
			$createdBy .= '<tr><td>';
			$createdBy .= $langs->trans('UpdatedBy');
			$commentUser = new User($db);
			$commentUser->fetch($obj->fk_user_modif);
			$createdBy .= activeContributorUrl($commentUser, 1);
			$createdBy .= '</td>';
			$createdBy .= '<td>'. $langs->trans('The'). ' ' . dol_print_date($obj->tms, 'dayhour', 'tzuserrel').' </td></tr></table>';
		}

		// [#106] Bigger image for article in banner tab
		$object->picto = 'article_50@lareponse';
		dol_banner_tab($object, 'id', $linkback, 1, 'rowid', 'title', $tagDiv, '', 0, '', $createdBy);
		$object->picto = 'lareponse@lareponse';

		print '<div class="tabsAction tabs-article-multiselect" '.($conf->theme == 'quarantedeux'? 'style="margin:0px !important"' : '').'>'; // [#147]
		// Buttons for actions
		if ($action != 'presend' && $action != 'editline' && ($object->fk_user_creat == $user->id || $permissioncorrector)) {
			$parameters = array();
			$reshook = $hookmanager->executeHooks('addMoreActionsButtons', $parameters, $object, $action); // Note that $action and $object may have been modified by hook

			if ($reshook < 0) setEventMessages($hookmanager->error, $hookmanager->errors, 'errors');
			if (empty($reshook)) {
				// Send
				//print '<a class="butAction" href="'.$_SERVER["PHP_SELF"].'?id='.$object->id.'&action=presend&mode=init#formmailbeforetitle">'.$langs->trans('SendMail').'</a>'."\n";

				// Back to draft
				if ($object->status == $object::STATUS_VALIDATED) {
					if ($permissiontoadd) {
						print '<a class="butAction" href="'.$_SERVER['PHP_SELF'].'?id='.$object->id.'&action=confirm_setdraft&confirm=yes">'.$langs->trans("SetToDraft").'</a>';
					}
				}
				// Multiselect buttons
				displayMultiSelectButtonModify($object, $permissiontoadd);
				displayMultiSelectButtonPublish($object, $permissiontoread, $permissiontoexport, $user);
			}
		} else if ($permissiontoexport) {
			print '<a class="butAction" href="'.$_SERVER["PHP_SELF"].'?id='.$object->id.'&amp;action=export">'.$langs->trans('Export').'</a>'."\n";
		} else {
			print '<a class="butActionRefused classfortooltip" href="#" title="'.dol_escape_htmltag($langs->trans("NotEnoughPermissions")).'">'.$langs->trans('Export').'</a>'."\n";
		}

		// [#128] Display on the same line all buttons @Favorite
		print'<br><div>';

		$color = '';
		if (favoriteExists($user->id, $object->id) == 1)
			$color = '#ffd633';
		else $color .= 'white';
		Print'<div style="width:100px;" href="#" id="cardFavStar" class="butAction" user-id="'.$user->id.'" article-id="'.$object->id.'">'.$langs->trans('LaReponseFavorite').' <i class="fa fa-star" style="color:'.$color.'">';
		print'</i></div>'; // If the star icon is clicked, run the action "put_in_fav"
		print'</div>';
		print'</div>';


		print '<div class="fichecenter">';
		//print '<div class="fichehalfleft">';
		print '<div style="border: none" class="underbanner clearboth"></div>';

		//$object->showOutputField('');
		//print $object->showOutputField($val, $key, $value, '', '', '', 0);
		print '<div class="lareponse_article">';
		// This functions replaces all <br /> by ''
		print changeContentForMermaid($object->content);
		print '</div>';

		// Integrate mermaid on lareponse article
		print '<script src="'.dol_buildpath('lareponse/js/mermaid.js', 2).'"></script>';

		// Other attributes. Fields from hook formObjectOptions and Extrafields.
		include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_view.tpl.php';

		print '</div>';
		//print '</div>';

		print '<div class="clearboth"></div>';

		dol_fiche_end();


		/*
		 * Lines
		 */

		if ($action == 'deletecom') {
			print $form->formconfirm($_SERVER["PHP_SELF"].'?id='.$id.'&commentid='.GETPOST('commentid', 'int'), $langs->trans('DeleteComment'),  $langs->trans('DeleteCommentMsg'), "deletecomment", null, 'no', 2, 370, 500, 0);
		}

		if (!empty($object->table_element_line)) {
			// Show object lines
			$result = $object->getLinesArray();

			print '	<form name="addproduct" id="addproduct" action="'.$_SERVER["PHP_SELF"].'?id='.$object->id.(($action != 'editline') ? '#addline' : '#line_'.GETPOST('lineid', 'int')).'" method="POST">
    	<input type="hidden" name="action" value="' . (($action != 'editline') ? 'addline' : 'updateline').'">
    	<input type="hidden" name="mode" value="">
    	<input type="hidden" name="id" value="' . $object->id.'">
    	';

			if (!empty($conf->use_javascript_ajax) && $object->status == 0) {
				include DOL_DOCUMENT_ROOT.'/core/tpl/ajaxrow.tpl.php';
			}

			print '<div class="div-table-responsive-no-min">';
			if (!empty($object->lines) || ($object->status == $object::STATUS_DRAFT && $permissiontoadd && $action != 'selectlines' && $action != 'editline')) {
				print '<table id="tablelines" class="noborder noshadow" width="100%">';
			}

			if (!empty($object->lines)) {
				$object->printObjectLines($action, $mysoc, null, GETPOST('lineid', 'int'), 1);
			}

			// Form to add new line
			if ($object->status == 0 && $permissiontoadd && $action != 'selectlines') {
				if ($action != 'editline') {
					// Add products/services form
					$object->formAddObjectLine(1, $mysoc, $soc);

					$parameters = array();
					$reshook = $hookmanager->executeHooks('formAddObjectLine', $parameters, $object, $action); // Note that $action and $object may have been modified by hook
				}
			}

			if (!empty($object->lines) || ($object->status == $object::STATUS_DRAFT && $permissiontoadd && $action != 'selectlines' && $action != 'editline')) {
				print '</table>';
			}
			print '</div>';

			print "</form>\n";
		}




		// Comment

		$comment = new ArticleComment($db);

		print '<div class="underrefbanner clearboth"></div>';


		print '<div class="fichecenter">';

		print '<div class="titre"><h2 style="margin: 0.25em 0"><span id="lareponse-article-icon" class="fas fa-chevron-up"></span> '.$langs->trans('CommentSpace').'</h2></div>';

		$commentNbr = $comment->getCommentNbr($id);
		print '<div id="comment-section" class="tabBar">';
		print '<h4 style="margin: 0.5em 0px"><i class="far fa-comment-alt fa-1x"></i>&nbsp;&nbsp;'.$commentNbr.' '.$langs->trans('Comments').'</h4>';

		print '<form method="POST" action="'.$_SERVER["PHP_SELF"].'?id='.$id.'">';
		if ((float) DOL_VERSION >= 11) {
			print '<input type="hidden" name="token" value="' . newToken() . '">';
		} else {
			print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
		}
		print '<input type="hidden" name="action" value="comment">';
		$doleditor = new DolEditor('content', $comment->content, '', 100, 'dolibarr_notes', 'In', true, true, $conf->fckeditor->enabled, ROWS_7, '90%');
		$doleditor->Create();
		print '<br>';
		print '<input type="submit" class="button" name="post" value="Poster" style="float: right">';
		print '<br>';
		print '</form>';

		// Comment List section
		$commentOffset = 0;
		$commentLimit = 5;
		$comments = $comment->getCommentWithPagination($id, $_SESSION['order'], $commentOffset, $commentLimit);
		if ($commentNbr > 0) {
			print '<div id="comments" data-limit="'.$commentLimit.'" data-total-comment="'.$commentNbr.'" data-order="'.$_SESSION['order'].'" data-article-id="'.$id.'">';
			if ($_SESSION['order'] == 'DESC')
				print '<div>'.$langs->trans('FilterByDate').'&nbsp;<a href="' . $_SERVER['PHP_SELF'] . '?id=' . $id . '&order=ASC"><i class="fa fa-sort-amount-asc fa-rotate-180 fa-flip-vertical" aria-hidden="true"></i></a></div>';
			else print '<div>'.$langs->trans('FilterByDate').'&nbsp;<a href="' . $_SERVER['PHP_SELF'] . '?id=' . $id . '&order=DESC"><i class="fa fa-sort-amount-asc" aria-hidden="true"></i></i></a></div>';

			$commentCounter = 0;
			foreach ($comments as $res) {
				$commentUser = new User($db);
				$commentUser->fetch($res['author']);
				print '<div id="commentBox'.($commentOffset + $commentCounter).'" class="commentBox">';
				print '<table class="tableComment" style="width: 100%; margin: 0; padding: 0"><tbody>';
				print '<tr><td class="commentAuthor"><p>' . $commentUser->getNomUrl(-1, '', '', '', '', '', '', 'commentTitle') . '</p></td>';
				print '<td class="commentDate"><p style="float: right">' . dol_print_date($res['date'], 'dayhour') . '</p></td></tr>';
				print '<tr><td class="commentContent"><p>' . changeContentForMermaid($res['content']) . '</p></td></tr>';
				if ($res['author'] == $user->id) {
					print '<tr><td></td><td style="text-align: end" class="commentDeleteLink"><a href="' . $_SERVER['PHP_SELF'] . '?id=' . $id . '&action=deletecom&commentid=' . $res['rowid'] . '" style="color: red;"><i class="fa fa-trash-o" aria-hidden="true"></i></a></td></tr>';
				}
				print '</tbody></table>';
				print '</div>';

				$commentCounter++;
			}
			print '</div>';
		}

		print '<div id="commentLoader"><i class="fa fa-spinner fa-3x fa-spin"></i></div>';

		print '</div>';
		print '</div>';
	} else {
		// We are in print mode, we only show the content if the user can read
		if ($permissiontoread) {
			print '<div class="fichecenter">';
			print $object->content;

			// Integrate mermaid on lareponse article
			print '<script src="'.dol_buildpath('lareponse/js/mermaid.js', 2).'"></script>';

			print '</div>';
		} else {
			accessforbidden();
		}
	}
}

// End of page
llxFooter();
$db->close();
