<?php
/*
 * Copyright (C) 2022-2022 Ayoub Bayed      <ayoub@code42.fr>

 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * \file    lareponse/class/actions_lareponse.class.php
 * \ingroup lareponse
 * \brief   Example hook overload.
 *
 * Put detailed description here.
 */


/**
 * Class ActionsLaReponse
 */
class ActionsLaReponse
{
	/**
	 * @var DoliDB Database handler.
	 */
	public $db;
	/**
	 * @var string Error
	 */
	public $error = '';
	/**
	 * @var array Errors
	 */
	public $errors = array();

	/**
	 * @var array Hook results. Propagated to $hookmanager->resArray for later reuse
	 */
	public $results = array();

	/**
	 * @var string String displayed by executeHook() immediately after return
	 */
	public $resprints;

	/**
	 * Constructor
	 *
	 * @param DoliDB $db Database handler
	 */
	public function __construct($db)
	{
		$this->db = $db;
	}

	/* Add here any other hooked methods... */

	/**
	 * addSearchEntry Method Hook Call
	 *
	 * @param  array  $parameters  parameters
	 * @param  Object $object      Object to use hooks on
	 * @param  string $action      Action code on calling page ('create', 'edit', 'view', 'add', 'update', 'delete'...)
	 * @param  object $hookmanager class instance
	 * @return int
	 */
	public function addSearchEntry($parameters, &$object, &$action, $hookmanager)
	{
		global $conf, $langs, $user;

		$position = 30;
		$langs->load('lareponse@lareponse');

		if (!empty($conf->lareponse->enabled) && $user->rights->lareponse->article->read) {
			$arrayresult['articlelist'] = array(
				'position' => $position,
				'text' => $langs->trans("LaReponseArticle"),
				'url' => dol_buildpath('/lareponse/article_list.php', 1)
			);
		}

		$this->results = $arrayresult;
		return 0;
	}

	/**
	 * Get the module header for contactus tab
	 *
	 * @param   array       $parameters         Array of parameter (we only use $parameters['module'] to check module header to display)
	 * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
	 */
	public function generateContactUsTabHeader($parameters)
	{
		dol_include_once("/lareponse/lib/lareponse.lib.php");

		// Check if we need to display contact us information header
		if ($parameters['module'] == 'modLareponse') {
			$this->results['head'] = generateLareponseDocumentationHeader();
			$this->results['active_tab'] = 'contactus';
			$this->results['langs'] = 'lareponse@lareponse';
			$this->results['header_icon'] = '';
			return 1;
		}
	}

	/**
	 * Get the module header for information tab
	 *
	 * @param   array       $parameters         Array of parameter (we only use $parameters['module'] to check module header to display)
	 * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
	 */
	public function generateInformationTabHeader($parameters)
	{
		dol_include_once('/lareponse/lib/lareponse.lib.php');

		if ($parameters['module'] == 'modLareponse') {
			$this->results['head'] = lareponseAdminPrepareHead();
			$this->results['active_tab'] = 'information';
			$this->results['langs'] = 'lareponse@lareponse';
			$this->results['header_icon'] = '';
			return 1;
		}
	}

	/**
	 * Get the module header for migration tab
	 *
	 * @param   array       $parameters         Array of parameter (we only use $parameters['module'] to check module header to display)
	 * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
	 */
	public function generateMigrationTabHeader($parameters)
	{
		dol_include_once('/lareponse/lib/lareponse.lib.php');

		// Check if we need to display contrat plus information header
		if ($parameters['module'] == 'modLareponse') {
			$this->results['head'] = lareponseAdminPrepareHead();
			$this->results['active_tab'] = 'migration';
			$this->results['langs'] = 'lareponse@lareponse';
			$this->results['header_icon'] = '';
			return 1;
		}
	}
}
