<?php
/* Copyright (C) 2001-2005 Rodolphe Quiedeville <rodolphe@quiedeville.org>
 * Copyright (C) 2004-2015 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2005-2012 Regis Houssin        <regis.houssin@inodbox.com>
 * Copyright (C) 2015      Jean-François Ferry	<jfefe@aternatik.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

/**
 *	\file       lareponse/lareponseindex.php
 *	\ingroup    lareponse
 *	\brief      Home page of lareponse top menu
 */

// Load Dolibarr environment
$res=0;
// Try main.inc.php into web root known defined into CONTEXT_DOCUMENT_ROOT (not always defined)
if (! $res && ! empty($_SERVER["CONTEXT_DOCUMENT_ROOT"])) $res=@include $_SERVER["CONTEXT_DOCUMENT_ROOT"]."/main.inc.php";
// Try main.inc.php into web root detected using web root calculated from SCRIPT_FILENAME
$tmp=empty($_SERVER['SCRIPT_FILENAME'])?'':$_SERVER['SCRIPT_FILENAME'];$tmp2=realpath(__FILE__); $i=strlen($tmp)-1; $j=strlen($tmp2)-1;
while ($i > 0 && $j > 0 && isset($tmp[$i]) && isset($tmp2[$j]) && $tmp[$i]==$tmp2[$j]) { $i--; $j--; }
if (! $res && $i > 0 && file_exists(substr($tmp, 0, ($i+1))."/main.inc.php")) $res=@include substr($tmp, 0, ($i+1))."/main.inc.php";
if (! $res && $i > 0 && file_exists(dirname(substr($tmp, 0, ($i+1)))."/main.inc.php")) $res=@include dirname(substr($tmp, 0, ($i+1)))."/main.inc.php";
// Try main.inc.php using relative path
if (! $res && file_exists("../main.inc.php")) $res=@include "../main.inc.php";
if (! $res && file_exists("../../main.inc.php")) $res=@include "../../main.inc.php";
if (! $res && file_exists("../../../main.inc.php")) $res=@include "../../../main.inc.php";
if (! $res) die("Include of main fails");

require_once DOL_DOCUMENT_ROOT.'/core/class/html.formfile.class.php';
dol_include_once('/lareponse/lib/lareponse_article.lib.php');
dol_include_once('/lareponse/class/article.class.php');
dol_include_once('/lareponse/lib/lareponse_favorites.lib.php');
dol_include_once('/lareponse/lib/lareponse.lib.php');

// Load translation files required by the page
$langs->loadLangs(array("lareponse@lareponse"));

$action=GETPOST('action', 'alpha');


// Security check
//if (! $user->rights->lareponse->myobject->read) accessforbidden();
$socid=GETPOST('socid', 'int');
if (isset($user->socid) && $user->socid > 0) {
	$action = '';
	$socid = $user->socid;
}

$max = $conf->global->LA_REPONSE_WIDGET_NUMBER ?: $conf->global->MAIN_SIZE_SHORTLIST_LIMIT;
$now=dol_now();


/*
 * Actions
 */

// None


/*
 * View
 */

$form = new Form($db);
$formfile = new FormFile($db);

llxHeader("", $langs->trans("LareponseArea"));

print load_fiche_titre($langs->trans("LareponseArea"), '', 'object_lareponse62@lareponse');

/*
 * Demo text
 */
if ($conf->global->LAREPONSE_WIZARD_ACTIVE == 1 && !empty($conf->global->LAREPONSE_WIZARD_INDEX)) {
	print '<div class="gp-demo-div">';
	print $conf->global->LAREPONSE_WIZARD_INDEX;
	print '</div>';
	print '<div class="clearboth"></div>';
}

print '<div class="fichecenter"><div class="fichethirdleft">';

// 5 last articles
if (! empty($conf->lareponse->enabled) && $user->rights->lareponse->article->read) {
	$articles = getLastArticlesCreated($max, $user);
	$num = count($articles);

	print '<table class="noborder centpercent">';
	print '<tr class="liste_titre">';
	print '<th colspan="4">'.$langs->trans("LastArticles", $max).($num ? '&nbsp;<span class="badge marginleftonlyshort">'.$num.'</span>' : '').'</th></tr>';
	if (!empty($articles)) {
		foreach ($articles as $article) {
			$obj = new Article($db);
			$obj->id = $article->rowid;
			$obj->date_creation = $article->datec;
			$obj->content = $article->content;
			$obj->title = $article->title;
			$obj->fk_user_creat = $article->author;
			$obj->private = $article->private;

			// Article name
			print '<tr><td>';
			print $obj->getNomUrl(1);
			print '</td>';
			// User name
			print '<td class="nowrap">';
			$commentUser = new User($db);
			$commentUser->fetch($obj->fk_user_creat);
			print activeContributorUrl($commentUser, -1);
			print '</td>';
			// Private label
			print '<td class="nowrap">';
			if ($obj->private == 0)
				print $langs->trans('Public');
			else print $langs->trans('Private');
			print '</td>';
			// Creation date
			print '<td class="right" class="nowrap">'.dol_print_date($db->jdate($obj->date_creation), 'dayhour').'</td></tr>';
		}
	} else {
		// Print no data image
		print '<tr class="oddeven"><td colspan="3">';
		print '<div class="noDataContainer">';
		print '<div class="noDataIcon"><img src="'.dol_buildpath('/lareponse/img/no_data.svg', 1).'"></div>';
		print '<div class="noDataText">'.$langs->trans("NoArticle").'</div>';
		print '</div>';
		print '</td></tr>';
	}
	print "</table></br>";
}


print '</div><div class="fichetwothirdright"><div class="ficheaddleft">';

if (! empty($conf->lareponse->enabled) && $user->rights->lareponse->article->read) {
	$articles = getLastArticlesUpdated($max, $user);
	$num = count($articles);

	print '<table class="noborder centpercent">';
	print '<tr class="liste_titre">';
	print '<th colspan="4">'.$langs->trans("LastArticlesUpdated", $max).($num ? '&nbsp;<span class="badge marginleftonlyshort">'.$num.'</span>' : '').'</th></tr>';

	if (!empty($articles)) {
		foreach ($articles as $article) {
			$obj = new Article($db);
			$obj->id = $article->rowid;
			$obj->tms = $article->dateu;
			$obj->content = $article->content;
			$obj->title = $article->title;
			$obj->fk_user_creat = $article->author;
			$obj->fk_user_modif = $article->update_author;
			$obj->private = $article->private;
			// Article name
			print '<tr><td>';
			print $obj->getNomUrl(1);
			print '</td>';
			// User name
			print '<td class="nowrap">';
			$commentUser = new User($db);
			$commentUser->fetch($obj->fk_user_modif);
			//print $commentUser->getNomUrl(-1);
			print activeContributorUrl($commentUser, -1);
			print '</td>';
			// Private label
			print '<td class="nowrap">';
			if ($obj->private == 0)
				print $langs->trans('Public');
			else print $langs->trans('Private');
			print '</td>';
			// Creation date
			print '<td class="right" class="nowrap">'.dol_print_date($db->jdate($obj->tms), 'dayhour', 'tzuserrel').'</td></tr>';
		}
	} else {
		// Print no data image
		print '<tr class="oddeven"><td colspan="3">';
		print '<div class="noDataContainer">';
		print '<div class="noDataIcon"><img src="'.dol_buildpath('/lareponse/img/no_data.svg', 1).'"></div>';
		print '<div class="noDataText">'.$langs->trans("NoArticle").'</div>';
		print '</div>';
		print '</td></tr>';
	}
	print "</table><br>";
}

print '</div></div></div>';

/* ----------- */
/* Second row  */
/* ----------- */
print '<div class="fichecenter"><div class="fichethirdleft">';

if (! empty($conf->lareponse->enabled) && $user->rights->lareponse->article->read) {
	$contributors = getMostActiveContributor($max);
	$num = count($contributors);

	print '<table class="noborder centpercent">';
	print '<tr class="liste_titre">';
	print '<th colspan="3">'.$langs->trans("MostActiveContributor", $max).($num ? '&nbsp;<span class="badge marginleftonlyshort">'.$num.'</span>' : '').'</th></tr>';

	if (!empty($contributors)) {
		foreach ($contributors as $contributor) {
			$userObj = new User($db);
			$userObj->fetch($contributor->author);
			// User name
			print '<td class="nowrap">';
			print activeContributorUrl($userObj, -1);
			print '</td>';
			// Nb articles published
			print '<td class="nowrap">';
			print $contributor->nb_article.' '.($contributor->nb_article > 1 ? $langs->trans('articlesPublished') : $langs->trans('articlePublished'));
			print '</td>';
			print '</tr>';
		}
	} else {
		// Print no data image
		print '<tr class="oddeven"><td colspan="3">';
		print '<div class="noDataContainer">';
		print '<div class="noDataIcon"><img src="'.dol_buildpath('/lareponse/img/no_contributor.svg', 1).'"></div>';
		print '<div class="noDataText">'.$langs->trans("NoContributor").'</div>';
		print '</div>';
		print '</td></tr>';
	}
	print "</table><br>";
}

print '</div><div class="fichetwothirdright"><div class="ficheaddleft">';

/**
 * Favorites addon
 */
if (! empty($conf->lareponse->enabled) && $user->rights->lareponse->article->read) {
	$favorites = getUserFavoriteArticles($user->id);
	$num = count($favorites);

	// Get articles from favorites ids

	print '<table class="noborder centpercent">';
	print '<tr class="liste_titre">';
	print '<th colspan="4">'.$langs->trans("MyFavoritesArticles", $max).($num ? '&nbsp;<span class="badge marginleftonlyshort">'.$num.'</span>' : '').'</th></tr>';

	if (!empty($favorites)) {
		foreach ($favorites as $favorite) {
			$obj = new Article($db);
			$obj->id = $favorite->rowid;
			$obj->date_creation = $favorite->dateu;
			$obj->content = $favorite->content;
			$obj->title = $favorite->title;
			$obj->fk_user_creat = $favorite->author;
			$obj->private = $favorite->private;
			// Article name
			print '<tr><td class="indexFavStars">';
			print '<i class="fa fa-star"></i>';
			print $obj->getNomUrl(0);
			print '</td>';
			// User name
			print '<td class="nowrap">';
			$commentUser = new User($db);
			$commentUser->fetch($obj->fk_user_creat);
			print activeContributorUrl($commentUser, -1);
			print '</td>';
			// Private label
			print '<td class="nowrap">';
			if ($obj->private == 0)
				print $langs->trans('Public');
			else print $langs->trans('Private');
			print '</td>';
			// Creation date
			print '<td class="right" class="nowrap">'.dol_print_date($db->jdate($obj->date_creation), '%d/%m/%y %H:%M').'</td></tr>';
		}
	} else {
		// Print no data image
		print '<tr class="oddeven"><td colspan="3">';
		print '<div class="noDataContainer">';
		print '<div class="noFavIcon"><img src="'.dol_buildpath('/lareponse/img/no_favorite.svg', 1).'"></div>';
		print '<div class="noDataText">'.$langs->trans("NoFavorite").'</div>';
		print '</div>';
		print '</td></tr>';
	}
	print "</table><br>";
}
print '</div></div></div>';

// End of page
llxFooter();
$db->close();
