import { Page, expect, test } from "@playwright/test";
import * as dotenv from "dotenv";
dotenv.config({ path: require("find-config")(".env") });

const deleteArticle: number = 1; //CHANGE THIS IF YOU WANT (1 to delete articles, 0 to keep articles)
let article_title1 = "[PlayWright] Article 1 N°"+Math.floor(Math.random() * 3712478493);
let article_title2 = "[PlayWright] Article 2 N°"+Math.floor(Math.random() * 3712478493);
let article_title3 = "[PlayWright] Article 3 N°"+Math.floor(Math.random() * 3712478493);
let article_title4 = "[PlayWright] Article 4 N°"+Math.floor(Math.random() * 3712478493);
let expectedBadgeAdminValue = '3'; // Remplacez par la valeur attendue
let expectedBadgeUserValue = '2'; // Remplacez par la valeur attendue

function delay(time) {
  return new Promise(function (resolve) {
    setTimeout(resolve, time);
  });
}

/*
 * STEP 1 : Authentication with Admin acccount
 */
async function authenticateAdmin(page) {
  await page.goto(`${process.env.DOLIBARR_URL_BACKEND}`);
  await page.fill('#username', `${process.env.USER_BACKEND_ID_ADMIN}`);
  await page.fill('#password', `${process.env.USER_BACKEND_PASSWORD_ADMIN}`);
  page.on("console", (msg) => {
    console.log(msg);
  });
}

/*
 * STEP 2 : Admin reate an article with Product 1 tag and Product 2 tag
 */
async function ArticleProductTagsAdmin(page) {
  await delay(2000);
  await page.locator("#mainmenua_lareponse").click();
  await page.getByRole("link", { name: "Nouvel article" }).click();
  await page.locator("#title").fill(article_title1);
  await page.click('input.button[name="add"]');
  await page.getByRole('list').first().click();
  await page.click('div#list_tag_chosen ul.chosen-results li[data-option-array-index="0"]');
  await page.getByRole('list').first().click();
  await page.click('div#list_tag_chosen ul.chosen-results li[data-option-array-index="1"]');
  await page.click('input.button[name="save"]');
  await page.click('a#article.tab');
}

/*
 * STEP 3 : Admin create an article with Product Tag "Produit 1"
 */
async function ArticleProductTagOneAdmin(page) {
  await delay(2000);
  await page.getByRole("link", { name: "Nouvel article" }).click();
  await page.locator("#title").fill(article_title2);
  await page.click('input.button[name="add"]');

  await page.click('span#select2-private-container');
  const optionIndex = 1; 
  await page.click(`.select2-results__option:nth-child(${optionIndex + 1})`);

  await page.getByRole('list').first().click();
  await page.click('div#list_tag_chosen ul.chosen-results li[data-option-array-index="0"]');
  await page.click('input.button[name="save"]');
  await page.click('a#article.tab');

}

/*
 * STEP 4 : Admin create an article with Product Tag "Produit 2"
 */
async function ArticleProductTagTwoAdmin(page) {
  await delay(2000);
  await page.getByRole("link", { name: "Nouvel article" }).click();
  await page.locator("#title").fill(article_title3);
  await page.click('input.button[name="add"]');

  await page.click('span#select2-private-container');
  const optionIndex = 1; 
  await page.click(`.select2-results__option:nth-child(${optionIndex + 1})`);
  
  await page.getByRole('list').first().click();
  await page.click('div#list_tag_chosen ul.chosen-results li[data-option-array-index="1"]');
  await page.click('input.button[name="save"]');
  await page.click('a#article.tab');
}


/*
 * STEP 5 : Logout Admin
 */
async function logout(page) {
  await delay(2000);
  await page.goto(`${process.env.DOLIBARR_URL_BACKEND}/user/logout.php`);
}

/*
 * STEP 6 : Authenticate with User Account
 */
async function authenticateUser(page) {
  await page.goto(`${process.env.DOLIBARR_URL_BACKEND}`);
  await page.fill('#username', `${process.env.USER_BACKEND_ID_USER}`);
  await page.fill('#password', `${process.env.USER_BACKEND_PASSWORD_USER}`);
  page.on("console", (msg) => {
    console.log(msg);
  });
}

/*
 * STEP 7 : User create an article
 */
async function ArticleProductTagsUser(page) {
  await delay(2000);
  await page.locator("#mainmenua_lareponse").click();
  await page.getByRole("link", { name: "Nouvel article" }).click();
  await page.locator("#title").fill(article_title4);
  await page.click('input.button[name="add"]');

  await page.click('span#select2-private-container');
  const optionIndex = 1; 
  await page.click(`.select2-results__option:nth-child(${optionIndex + 1})`);
  await page.getByRole('list').first().click();
  await page.click('div#list_tag_chosen ul.chosen-results li[data-option-array-index="1"]');
  await page.getByRole("button", { name: "Save" }).click();
  await page.getByRole('link', { name: 'Related Articles' }).click();
  
}

/*
 * STEP 8 : Display the article that Admin can see
 */
async function DisplayArticlesForAdmin(page) {
  await delay(2000);
  await page.locator("#mainmenua_lareponse").click();
  await page.getByRole("link", { name: "Liste articles" }).click();
  await page.getByRole('link', { name: ' '+article_title1 }).click();
  await page.getByRole('link', { name: 'Related Articles' }).click();
  
}


/*
 * STEP 9 : Verification of associated articles for Admin Account
 */
async function verificationAdminArticle(page) {
  await delay(2000);
  let badgeElement = await page.$('.badge.marginleftonlyshort');
  let badgeValue = await badgeElement.textContent();
  console.log('Badge value:', badgeValue.trim());
  await expect(badgeValue.trim()).toBe(expectedBadgeAdminValue);
  if (badgeValue.trim() === expectedBadgeAdminValue) {
    await showTemporaryMessage(page, `Le badge pour les articles associés à Admin est bien à ${expectedBadgeAdminValue} articles.`);
  } else {
    await showTemporaryMessage(page, `Le badge devrait être à ${expectedBadgeAdminValue} articles, mais il est actuellement à ${badgeValue.trim()} articles.`);
  }
}

/*
 * STEP 10 : Verification of associated articles for User Account
 */
async function verificationUserArticle(page) {
  await delay(2000);
  let badgeElement = await page.$('.badge.marginleftonlyshort');
  let badgeValue = await badgeElement.textContent();
  console.log('Badge value:', badgeValue.trim());
  await expect(badgeValue.trim()).toBe(expectedBadgeUserValue);
  if (badgeValue.trim() === expectedBadgeUserValue) {
    await showTemporaryMessage(page, `Le badge pour les articles associés à User est bien à ${expectedBadgeUserValue} articles.`);
  } else {
    await showTemporaryMessage(page, `Le badge devrait être à ${expectedBadgeUserValue} articles, mais il est actuellement à ${badgeValue.trim()} articles.`);
  }
}

/*
 * STEP 11 : Delete All articles
 */
async function deleteAllArticles(page) {
  await page.locator("#mainmenua_lareponse").click();
  await page.getByRole("link", { name: "Liste articles" }).click();
  await page.locator('#checkforselects').check();
  await page.click('span#select2-massaction-container');
  const optionIndex = 1; 
  await page.click(`.select2-results__option:nth-child(${optionIndex + 1})`);
  const button1 = await page.waitForSelector('input[name="confirmmassaction"]');
  await button1.click();
  await page.selectOption('select[name="confirm"]', 'yes');
  const button2 = await page.waitForSelector('input.button.valignmiddle.confirmvalidatebutton.small');
  await button2.click();
}

async function showTemporaryMessage(page: Page, message: string) {
  const messageOverlay = await page.evaluateHandle((msg) => {
    const overlay = document.createElement('div');
    overlay.style.position = 'fixed';
    overlay.style.top = '50%';
    overlay.style.left = '50%';
    overlay.style.transform = 'translate(-50%, -50%)';
    overlay.style.background = 'rgba(0, 0, 0, 0.7)';
    overlay.style.color = 'white';
    overlay.style.padding = '40px';
    overlay.style.borderRadius = '10px';
    overlay.style.zIndex = '9999';
    overlay.style.fontSize = '20px'; 
    overlay.innerText = msg;

    document.body.appendChild(overlay);

    return overlay;
  }, message);

  await page.waitForTimeout(1500);
  await messageOverlay.dispose(); 
}

/*
 * STEP 9 : Display the article that Admin can see
 */
async function terminate(page) {
  await showTemporaryMessage(page, 'Test Terminée !!!');
  
}

test("Verification articles associés et badge", async ({ page }) => {
  test.setTimeout(120000);
  
  await authenticateAdmin(page);
  await ArticleProductTagsAdmin(page);
  await ArticleProductTagOneAdmin(page);
  await ArticleProductTagTwoAdmin(page);
  await logout(page);

  await authenticateUser(page);
  await ArticleProductTagsUser(page);

  await verificationUserArticle(page);
  await logout(page);

  await authenticateAdmin(page);
  await DisplayArticlesForAdmin(page);
  await verificationAdminArticle(page);
  if (deleteArticle == 1){
    await deleteAllArticles(page);
    await logout(page);
    await authenticateUser(page);
    await deleteAllArticles(page);
  }
  await page.evaluate(() => {
    setTimeout(() => {
      alert('Test Playwright Terminée à 100%');
    }, 1000); // 1000 millisecondes = 1 seconde
  });
  
});


